import {
  select,
  scaleLinear,
  scalePoint,
  extent,
  axisLeft,
  axisBottom,
  area,
  max,
  nest,
  scaleOrdinal,
  scaleTime,
  schemeCategory10
} from 'd3';

const svg = select('svg');

const w = +svg.attr('width');
const h = +svg.attr('height');

const render = data => {
   data.forEach(d => {
      // eslint-disable-next-line no-param-reassign
      d.value = +d.value;
    });

    const title = "Mock";

    const xValue = d => new Date(d.day);
    const xAxisLabel = "Month";

    const yValue = d => d.count;
    // const circleRadius = 6;
    const yAxisLabel = "Energy";

    const margin = { top: 60, right: 40, bottom: 88, left: 105 };
    const innerWidth = w - margin.left - margin.right;
    const innerHeight = h - margin.top - margin.bottom;

    const xScale = scaleTime()
      .domain(extent(data,xValue))
      .range([0, innerWidth]);

    const yScale = scaleLinear()
      .domain(extent(data,yValue))
      .range([0, innerHeight])
      .nice();

    const g = svg
      .append("g")
      .attr("transform", `translate(${margin.left},${margin.top})`);

    const xAxis = axisBottom(xScale)
      .tickSize(-innerHeight)
      .tickPadding(15);

    const yAxis = axisLeft(yScale)
      .tickSize(-innerWidth)
      .tickPadding(10);

    const yAxisG = g.append("g").call(yAxis);
    yAxisG.selectAll(".domain").remove();

    yAxisG
      .append("text")
      .attr("class", "axis-label")
      .attr("y", -60)
      .attr("x", -innerHeight / 2)
      .attr("fill", "black")
      .attr("transform", `rotate(-90)`)
      .attr("text-anchor", "middle")
      .text(yAxisLabel);

    const xAxisG = g
      .append("g")
      .call(xAxis)
      .attr("transform", `translate(0,${innerHeight})`);

    xAxisG.select(".domain").remove();

    xAxisG
      .append("text")
      .attr("class", "axis-label")
      .attr("y", 80)
      .attr("x", innerWidth / 2)
      .attr("fill", "black")
      .text(xAxisLabel);

    const lineGenerator = area()
      .x(d => xScale(xValue(d)))
    	.y0(innerHeight)
      .y1(d => yScale(yValue(d)));

  	const valueline = d3.line()
    	.x(d => xScale(xValue(d)))
    	.y(d => yScale(yValue(d)));
  
  		
  const nested = nest().key(d => d.stream_name).entries(data)
  
    var color = d3.scaleOrdinal(schemeCategory10)
  
  	const z = color;
   const source = g.selectAll(".area")
      .data(nested)
      .enter().append("g")
      .attr("class", function(d) { return `area ${d.key}`; })

  			source.append("path")
       .attr("d", function(d) { return lineGenerator(d.values); })
       .style("fill", function(d) { return z(d.key); });
  
      source.selectAll('.line')
      .data(nested)
      .enter()
      .append("path")
      .attr("class", "line")
  		.attr("stroke", d=> z(d.key))
  		.attr("stroke-width", "3")
      .attr("d", d => valueline(d.values));
  

    const defs = svg.append('defs');
  
svg
.select('defs')
.selectAll('linearGradient')
  .selectAll('stop')
    .data([0,2])
  .enter()
.append('stop')
.attr('stop-color', 'rgba(255,255,255,0.4)')
.attr('offset', '80%');
  
 defs
 .selectAll('.value-line')
  .data(nested)
  .enter()
  .append('clipPath')
  .attr('id', d => d.key + 'clip')
  .append('path')
  .attr('d', d => lineGenerator(d.values))
  .attr('class', 'value-line');

const clipPath = g
 	.selectAll('.clip-path')
  .data(nested)
  .enter()
  .append('g')
  .attr('clip-path', d => `url(#${d.key + 'clip'})`)
  .append('rect')
  .attr('x', 0)
  .attr('y', 0)
  .attr('width', w)
  .attr('height', h)
  .style('fill', d => `url(#${d.key})`)
  .attr('class', 'clip-path');
}; 

  


    const energyData =  [{"count": "262.813842773","stream_name":"ORP","day": "2019-11-03T16:45:00Z"},
                    {
                        "count": "262.529602051",
                        "stream_name": "ORP",
                        "day": "2019-11-03T17:00:00Z"
                    },
                    {
                        "count": "262.434875488",
                        "stream_name": "ORP",
                        "day": "2019-11-03T17:15:00Z"
                    },
                    {
                        "count": "262.434875488",
                        "stream_name": "ORP",
                        "day": "2019-11-03T17:30:00Z"
                    },
                    {
                        "count": "262.624359131",
                        "stream_name": "ORP",
                        "day": "2019-11-03T17:45:00Z"
                    },
                    {
                        "count": "262.908569336",
                        "stream_name": "ORP",
                        "day": "2019-11-03T18:00:00Z"
                    },
                    {
                        "count": "263.098052979",
                        "stream_name": "ORP",
                        "day": "2019-11-03T18:15:00Z"
                    },
                    {
                        "count": "263.287536621",
                        "stream_name": "ORP",
                        "day": "2019-11-03T18:30:00Z"
                    },
                    {
                        "count": "263.477020264",
                        "stream_name": "ORP",
                        "day": "2019-11-03T18:45:00Z"
                    },
                    {
                        "count": "263.761260986",
                        "stream_name": "ORP",
                        "day": "2019-11-03T19:00:00Z"
                    },
                    {
                        "count": "263.855987549",
                        "stream_name": "ORP",
                        "day": "2019-11-03T19:15:00Z"
                    },
                    {
                        "count": "264.045471191",
                        "stream_name": "ORP",
                        "day": "2019-11-03T19:30:00Z"
                    },
                    {
                        "count": "264.140228271",
                        "stream_name": "ORP",
                        "day": "2019-11-03T19:45:00Z"
                    },
                    {
                        "count": "264.140228271",
                        "stream_name": "ORP",
                        "day": "2019-11-03T20:00:00Z"
                    },
                    {
                        "count": "263.571777344",
                        "stream_name": "ORP",
                        "day": "2019-11-03T20:15:00Z"
                    },
                    {
                        "count": "263.098052979",
                        "stream_name": "ORP",
                        "day": "2019-11-03T20:30:00Z"
                    },
                    {
                        "count": "263.003326416",
                        "stream_name": "ORP",
                        "day": "2019-11-03T20:45:00Z"
                    },
                    {
                        "count": "263.098052979",
                        "stream_name": "ORP",
                        "day": "2019-11-03T21:00:00Z"
                    },
                    {
                        "count": "263.287536621",
                        "stream_name": "ORP",
                        "day": "2019-11-03T21:15:00Z"
                    },
                    {
                        "count": "263.477020264",
                        "stream_name": "ORP",
                        "day": "2019-11-03T21:30:00Z"
                    },
                    {
                        "count": "263.666503906",
                        "stream_name": "ORP",
                        "day": "2019-11-03T21:45:00Z"
                    },
                    {
                        "count": "263.855987549",
                        "stream_name": "ORP",
                        "day": "2019-11-03T22:00:00Z"
                    },
                    {
                        "count": "264.140228271",
                        "stream_name": "ORP",
                        "day": "2019-11-03T22:15:00Z"
                    },
                    {
                        "count": "264.234954834",
                        "stream_name": "ORP",
                        "day": "2019-11-03T22:30:00Z"
                    },
                    {
                        "count": "264.234954834",
                        "stream_name": "ORP",
                        "day": "2019-11-03T22:45:00Z"
                    },
                    {
                        "count": "264.234954834",
                        "stream_name": "ORP",
                        "day": "2019-11-03T23:00:00Z"
                    },
                    {
                        "count": "264.234954834",
                        "stream_name": "ORP",
                        "day": "2019-11-03T23:15:00Z"
                    },
                    {
                        "count": "263.666503906",
                        "stream_name": "ORP",
                        "day": "2019-11-03T23:30:00Z"
                    },
                    {
                        "count": "263.287536621",
                        "stream_name": "ORP",
                        "day": "2019-11-03T23:45:00Z"
                    },
                    {
                        "count": "263.192810059",
                        "stream_name": "ORP",
                        "day": "2019-11-04T00:00:00Z"
                    },
                    {
                        "count": "263.192810059",
                        "stream_name": "ORP",
                        "day": "2019-11-04T00:15:00Z"
                    },
                    {
                        "count": "263.287536621",
                        "stream_name": "ORP",
                        "day": "2019-11-04T00:30:00Z"
                    },
                    {
                        "count": "263.382293701",
                        "stream_name": "ORP",
                        "day": "2019-11-04T00:45:00Z"
                    },
                    {
                        "count": "263.571777344",
                        "stream_name": "ORP",
                        "day": "2019-11-04T01:00:00Z"
                    },
                    {
                        "count": "263.761260986",
                        "stream_name": "ORP",
                        "day": "2019-11-04T01:15:00Z"
                    },
                    {
                        "count": "263.950744629",
                        "stream_name": "ORP",
                        "day": "2019-11-04T01:30:00Z"
                    },
                    {
                        "count": "264.140228271",
                        "stream_name": "ORP",
                        "day": "2019-11-04T01:45:00Z"
                    },
                    {
                        "count": "264.234954834",
                        "stream_name": "ORP",
                        "day": "2019-11-04T02:00:00Z"
                    },
                    {
                        "count": "264.329711914",
                        "stream_name": "ORP",
                        "day": "2019-11-04T02:15:00Z"
                    },
                    {
                        "count": "264.329711914",
                        "stream_name": "ORP",
                        "day": "2019-11-04T02:30:00Z"
                    },
                    {
                        "count": "264.329711914",
                        "stream_name": "ORP",
                        "day": "2019-11-04T02:45:00Z"
                    },
                    {
                        "count": "264.045471191",
                        "stream_name": "ORP",
                        "day": "2019-11-04T03:00:00Z"
                    },
                    {
                        "count": "263.761260986",
                        "stream_name": "ORP",
                        "day": "2019-11-04T03:15:00Z"
                    },
                    {
                        "count": "263.571777344",
                        "stream_name": "ORP",
                        "day": "2019-11-04T03:30:00Z"
                    },
                    {
                        "count": "263.666503906",
                        "stream_name": "ORP",
                        "day": "2019-11-04T03:45:00Z"
                    },
                    {
                        "count": "263.761260986",
                        "stream_name": "ORP",
                        "day": "2019-11-04T04:00:00Z"
                    },
                    {
                        "count": "263.950744629",
                        "stream_name": "ORP",
                        "day": "2019-11-04T04:15:00Z"
                    },
                    {
                        "count": "264.140228271",
                        "stream_name": "ORP",
                        "day": "2019-11-04T04:30:00Z"
                    },
                    {
                        "count": "264.234954834",
                        "stream_name": "ORP",
                        "day": "2019-11-04T04:45:00Z"
                    },
                    {
                        "count": "264.424438477",
                        "stream_name": "ORP",
                        "day": "2019-11-04T05:00:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T05:15:00Z"
                    },
                    {
                        "count": "264.613922119",
                        "stream_name": "ORP",
                        "day": "2019-11-04T05:30:00Z"
                    },
                    {
                        "count": "264.613922119",
                        "stream_name": "ORP",
                        "day": "2019-11-04T05:45:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T06:00:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T06:15:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T06:30:00Z"
                    },
                    {
                        "count": "264.424438477",
                        "stream_name": "ORP",
                        "day": "2019-11-04T06:45:00Z"
                    },
                    {
                        "count": "264.234954834",
                        "stream_name": "ORP",
                        "day": "2019-11-04T07:00:00Z"
                    },
                    {
                        "count": "263.855987549",
                        "stream_name": "ORP",
                        "day": "2019-11-04T07:15:00Z"
                    },
                    {
                        "count": "263.666503906",
                        "stream_name": "ORP",
                        "day": "2019-11-04T07:30:00Z"
                    },
                    {
                        "count": "263.666503906",
                        "stream_name": "ORP",
                        "day": "2019-11-04T07:45:00Z"
                    },
                    {
                        "count": "263.666503906",
                        "stream_name": "ORP",
                        "day": "2019-11-04T08:00:00Z"
                    },
                    {
                        "count": "263.855987549",
                        "stream_name": "ORP",
                        "day": "2019-11-04T08:15:00Z"
                    },
                    {
                        "count": "264.045471191",
                        "stream_name": "ORP",
                        "day": "2019-11-04T08:30:00Z"
                    },
                    {
                        "count": "264.140228271",
                        "stream_name": "ORP",
                        "day": "2019-11-04T08:45:00Z"
                    },
                    {
                        "count": "264.329711914",
                        "stream_name": "ORP",
                        "day": "2019-11-04T09:00:00Z"
                    },
                    {
                        "count": "264.424438477",
                        "stream_name": "ORP",
                        "day": "2019-11-04T09:15:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T09:30:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T09:45:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T10:00:00Z"
                    },
                    {
                        "count": "264.519195557",
                        "stream_name": "ORP",
                        "day": "2019-11-04T10:15:00Z"
                    },
                    {
                        "count": "264.424438477",
                        "stream_name": "ORP",
                        "day": "2019-11-04T10:30:00Z"
                    },
                    {
                        "count": "9.59337329865",
                        "stream_name": "ph",
                        "day": "2019-11-03T16:45:00Z"
                    },
                    {
                        "count": "9.59375",
                        "stream_name": "ph",
                        "day": "2019-11-03T17:00:00Z"
                    },
                    {
                        "count": "9.59299564362",
                        "stream_name": "ph",
                        "day": "2019-11-03T17:15:00Z"
                    },
                    {
                        "count": "9.59261798859",
                        "stream_name": "ph",
                        "day": "2019-11-03T17:30:00Z"
                    },
                    {
                        "count": "9.59208488464",
                        "stream_name": "ph",
                        "day": "2019-11-03T17:45:00Z"
                    },
                    {
                        "count": "9.592461586",
                        "stream_name": "ph",
                        "day": "2019-11-03T18:00:00Z"
                    },
                    {
                        "count": "9.59170722961",
                        "stream_name": "ph",
                        "day": "2019-11-03T18:15:00Z"
                    },
                    {
                        "count": "9.59208488464",
                        "stream_name": "ph",
                        "day": "2019-11-03T18:30:00Z"
                    },
                    {
                        "count": "9.5943479538",
                        "stream_name": "ph",
                        "day": "2019-11-03T18:45:00Z"
                    },
                    {
                        "count": "9.59170722961",
                        "stream_name": "ph",
                        "day": "2019-11-03T19:00:00Z"
                    },
                    {
                        "count": "9.59133052826",
                        "stream_name": "ph",
                        "day": "2019-11-03T19:15:00Z"
                    },
                    {
                        "count": "9.59133052826",
                        "stream_name": "ph",
                        "day": "2019-11-03T19:30:00Z"
                    },
                    {
                        "count": "9.59133052826",
                        "stream_name": "ph",
                        "day": "2019-11-03T19:45:00Z"
                    },
                    {
                        "count": "9.59133052826",
                        "stream_name": "ph",
                        "day": "2019-11-03T20:00:00Z"
                    },
                    {
                        "count": "9.59041976929",
                        "stream_name": "ph",
                        "day": "2019-11-03T20:15:00Z"
                    },
                    {
                        "count": "9.5896654129",
                        "stream_name": "ph",
                        "day": "2019-11-03T20:30:00Z"
                    },
                    {
                        "count": "9.5896654129",
                        "stream_name": "ph",
                        "day": "2019-11-03T20:45:00Z"
                    },
                    {
                        "count": "9.59079647064",
                        "stream_name": "ph",
                        "day": "2019-11-03T21:00:00Z"
                    },
                    {
                        "count": "9.59079647064",
                        "stream_name": "ph",
                        "day": "2019-11-03T21:15:00Z"
                    },
                    {
                        "count": "9.59079647064",
                        "stream_name": "ph",
                        "day": "2019-11-03T21:30:00Z"
                    },
                    {
                        "count": "9.59079647064",
                        "stream_name": "ph",
                        "day": "2019-11-03T21:45:00Z"
                    },
                    {
                        "count": "9.59041976929",
                        "stream_name": "ph",
                        "day": "2019-11-03T22:00:00Z"
                    },
                    {
                        "count": "9.59041976929",
                        "stream_name": "ph",
                        "day": "2019-11-03T22:15:00Z"
                    },
                    {
                        "count": "9.59041976929",
                        "stream_name": "ph",
                        "day": "2019-11-03T22:30:00Z"
                    },
                    {
                        "count": "9.59041976929",
                        "stream_name": "ph",
                        "day": "2019-11-03T22:45:00Z"
                    },
                    {
                        "count": "9.59041976929",
                        "stream_name": "ph",
                        "day": "2019-11-03T23:00:00Z"
                    },
                    {
                        "count": "9.5902633667",
                        "stream_name": "ph",
                        "day": "2019-11-03T23:15:00Z"
                    },
                    {
                        "count": "9.58988666534",
                        "stream_name": "ph",
                        "day": "2019-11-03T23:30:00Z"
                    },
                    {
                        "count": "9.59177207947",
                        "stream_name": "ph",
                        "day": "2019-11-03T23:45:00Z"
                    },
                    {
                        "count": "9.59155082703",
                        "stream_name": "ph",
                        "day": "2019-11-04T00:00:00Z"
                    },
                    {
                        "count": "9.58928775787",
                        "stream_name": "ph",
                        "day": "2019-11-04T00:15:00Z"
                    },
                    {
                        "count": "9.5896654129",
                        "stream_name": "ph",
                        "day": "2019-11-04T00:30:00Z"
                    },
                    {
                        "count": "9.58928775787",
                        "stream_name": "ph",
                        "day": "2019-11-04T00:45:00Z"
                    },
                    {
                        "count": "9.5896654129",
                        "stream_name": "ph",
                        "day": "2019-11-04T01:00:00Z"
                    },
                    {
                        "count": "9.5887556076",
                        "stream_name": "ph",
                        "day": "2019-11-04T01:15:00Z"
                    },
                    {
                        "count": "9.5887556076",
                        "stream_name": "ph",
                        "day": "2019-11-04T01:30:00Z"
                    },
                    {
                        "count": "9.5887556076",
                        "stream_name": "ph",
                        "day": "2019-11-04T01:45:00Z"
                    },
                    {
                        "count": "9.58891105652",
                        "stream_name": "ph",
                        "day": "2019-11-04T02:00:00Z"
                    },
                    {
                        "count": "9.58853435516",
                        "stream_name": "ph",
                        "day": "2019-11-04T02:15:00Z"
                    },
                    {
                        "count": "9.58853435516",
                        "stream_name": "ph",
                        "day": "2019-11-04T02:30:00Z"
                    },
                    {
                        "count": "9.58928775787",
                        "stream_name": "ph",
                        "day": "2019-11-04T02:45:00Z"
                    },
                    {
                        "count": "9.58891105652",
                        "stream_name": "ph",
                        "day": "2019-11-04T03:00:00Z"
                    },
                    {
                        "count": "9.58853435516",
                        "stream_name": "ph",
                        "day": "2019-11-04T03:15:00Z"
                    },
                    {
                        "count": "9.58815670013",
                        "stream_name": "ph",
                        "day": "2019-11-04T03:30:00Z"
                    },
                    {
                        "count": "9.58777999878",
                        "stream_name": "ph",
                        "day": "2019-11-04T03:45:00Z"
                    },
                    {
                        "count": "9.58777999878",
                        "stream_name": "ph",
                        "day": "2019-11-04T04:00:00Z"
                    },
                    {
                        "count": "9.58755779266",
                        "stream_name": "ph",
                        "day": "2019-11-04T04:15:00Z"
                    },
                    {
                        "count": "9.58718013763",
                        "stream_name": "ph",
                        "day": "2019-11-04T04:30:00Z"
                    },
                    {
                        "count": "9.58680343628",
                        "stream_name": "ph",
                        "day": "2019-11-04T04:45:00Z"
                    },
                    {
                        "count": "9.58982086182",
                        "stream_name": "ph",
                        "day": "2019-11-04T05:00:00Z"
                    },
                    {
                        "count": "9.5860490799",
                        "stream_name": "ph",
                        "day": "2019-11-04T05:15:00Z"
                    },
                    {
                        "count": "9.58529472351",
                        "stream_name": "ph",
                        "day": "2019-11-04T05:30:00Z"
                    },
                    {
                        "count": "9.58529472351",
                        "stream_name": "ph",
                        "day": "2019-11-04T05:45:00Z"
                    },
                    {
                        "count": "9.58453941345",
                        "stream_name": "ph",
                        "day": "2019-11-04T06:00:00Z"
                    },
                    {
                        "count": "9.58453941345",
                        "stream_name": "ph",
                        "day": "2019-11-04T06:15:00Z"
                    },
                    {
                        "count": "9.58378505707",
                        "stream_name": "ph",
                        "day": "2019-11-04T06:30:00Z"
                    },
                    {
                        "count": "9.5841627121",
                        "stream_name": "ph",
                        "day": "2019-11-04T06:45:00Z"
                    },
                    {
                        "count": "9.58340835571",
                        "stream_name": "ph",
                        "day": "2019-11-04T07:00:00Z"
                    },
                    {
                        "count": "9.58303070068",
                        "stream_name": "ph",
                        "day": "2019-11-04T07:15:00Z"
                    },
                    {
                        "count": "9.58318519592",
                        "stream_name": "ph",
                        "day": "2019-11-04T07:30:00Z"
                    },
                    {
                        "count": "9.58318519592",
                        "stream_name": "ph",
                        "day": "2019-11-04T07:45:00Z"
                    },
                    {
                        "count": "9.58243083954",
                        "stream_name": "ph",
                        "day": "2019-11-04T08:00:00Z"
                    },
                    {
                        "count": "9.58243083954",
                        "stream_name": "ph",
                        "day": "2019-11-04T08:15:00Z"
                    },
                    {
                        "count": "9.58205318451",
                        "stream_name": "ph",
                        "day": "2019-11-04T08:30:00Z"
                    },
                    {
                        "count": "9.58280754089",
                        "stream_name": "ph",
                        "day": "2019-11-04T08:45:00Z"
                    },
                    {
                        "count": "9.5822763443",
                        "stream_name": "ph",
                        "day": "2019-11-04T09:00:00Z"
                    },
                    {
                        "count": "9.58189964294",
                        "stream_name": "ph",
                        "day": "2019-11-04T09:15:00Z"
                    },
                    {
                        "count": "9.58189964294",
                        "stream_name": "ph",
                        "day": "2019-11-04T09:30:00Z"
                    },
                    {
                        "count": "9.58152198792",
                        "stream_name": "ph",
                        "day": "2019-11-04T09:45:00Z"
                    },
                    {
                        "count": "9.58265399933",
                        "stream_name": "ph",
                        "day": "2019-11-04T10:00:00Z"
                    },
                    {
                        "count": "9.58318519592",
                        "stream_name": "ph",
                        "day": "2019-11-04T10:15:00Z"
                    },
                    {
                        "count": "9.58054447174",
                        "stream_name": "ph",
                        "day": "2019-11-04T10:30:00Z"
                    }
                ];
      
    render(energyData);
